#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest


class TestThings(unittest.TestCase):
    def test_stuff(self):
        pass


if __name__ == '__main__':
    import sys
    sys.exit(unittest.main())
